pub fn wasm_analyze_spell_desc(
input: &str,
self_spell_id: u32,
) -> WasmAnalyzeResultExpand description
Analyze a spell description and return its data dependencies.
pub fn wasm_analyze_spell_desc(
input: &str,
self_spell_id: u32,
) -> WasmAnalyzeResultAnalyze a spell description and return its data dependencies.